summaryrefslogtreecommitdiff
path: root/lib/rake
diff options
context:
space:
mode:
Diffstat (limited to 'lib/rake')
-rw-r--r--lib/rake/packagetask.rb3
-rw-r--r--lib/rake/rdoctask.rb92
2 files changed, 78 insertions, 17 deletions
diff --git a/lib/rake/packagetask.rb b/lib/rake/packagetask.rb
index 75bf41c457..de14fc77d8 100644
--- a/lib/rake/packagetask.rb
+++ b/lib/rake/packagetask.rb
@@ -42,7 +42,7 @@ module Rake
# end
#
class PackageTask < TaskLib
- # Name of the package.
+ # Name of the package (from the GEM Spec).
attr_accessor :name
# Version of the package (e.g. '1.3.2').
@@ -120,7 +120,6 @@ module Rake
task :package => ["#{package_dir}/#{file}"]
file "#{package_dir}/#{file}" => [package_dir_path] + package_files do
chdir(package_dir) do
- sh %{env}
sh %{#{@tar_command} #{flag}cvf #{file} #{package_name}}
end
end
diff --git a/lib/rake/rdoctask.rb b/lib/rake/rdoctask.rb
index 33c8675b9e..de020f4d87 100644
--- a/lib/rake/rdoctask.rb
+++ b/lib/rake/rdoctask.rb
@@ -8,7 +8,7 @@ module Rake
#
# The RDocTask will create the following targets:
#
- # [<b><em>rdoc</em></b>]
+ # [<b>:<em>rdoc</em></b>]
# Main task for this RDOC task.
#
# [<b>:clobber_<em>rdoc</em></b>]
@@ -19,13 +19,18 @@ module Rake
# Rebuild the rdoc files from scratch, even if they are not out
# of date.
#
- # Simple Example:
+ # Simple example:
#
# Rake::RDocTask.new do |rd|
# rd.main = "README.rdoc"
# rd.rdoc_files.include("README.rdoc", "lib/**/*.rb")
# end
#
+ # The +rd+ object passed to the block is an RDocTask object. See the
+ # attributes list for the RDocTask class for available customization options.
+ #
+ # == Specifying different task names
+ #
# You may wish to give the task a different name, such as if you are
# generating two sets of documentation. For instance, if you want to have a
# development set of documentation including private methods:
@@ -39,6 +44,16 @@ module Rake
# The tasks would then be named :<em>rdoc_dev</em>, :clobber_<em>rdoc_dev</em>, and
# :re<em>rdoc_dev</em>.
#
+ # If you wish to have completely different task names, then pass a Hash as
+ # first argument. With the <tt>:rdoc</tt>, <tt>:clobber_rdoc</tt> and
+ # <tt>:rerdoc</tt> options, you can customize the task names to your liking.
+ # For example:
+ #
+ # Rake::RDocTask.new(:rdoc => "rdoc", :clobber_rdoc => "rdoc:clean", :rerdoc => "rdoc:force")
+ #
+ # This will create the tasks <tt>:rdoc</tt>, <tt>:rdoc_clean</tt> and
+ # <tt>:rdoc:force</tt>.
+ #
class RDocTask < TaskLib
# Name of the main, top level task. (default is :rdoc)
attr_accessor :name
@@ -46,7 +61,7 @@ module Rake
# Name of directory to receive the html output files. (default is "html")
attr_accessor :rdoc_dir
- # Title of RDoc documentation. (default is none)
+ # Title of RDoc documentation. (defaults to rdoc's default)
attr_accessor :title
# Name of file to be used as the main, top level file of the
@@ -59,14 +74,24 @@ module Rake
# List of files to be included in the rdoc generation. (default is [])
attr_accessor :rdoc_files
- # List of options to be passed rdoc. (default is [])
+ # Additional list of options to be passed rdoc. (default is [])
attr_accessor :options
- # Run the rdoc process as an external shell (default is false)
+ # Whether to run the rdoc process as an external shell (default is false)
attr_accessor :external
- # Create an RDoc task named <em>rdoc</em>. Default task name is +rdoc+.
- def initialize(name=:rdoc) # :yield: self
+ attr_accessor :inline_source
+
+ # Create an RDoc task with the given name. See the RDocTask class overview
+ # for documentation.
+ def initialize(name = :rdoc) # :yield: self
+ if name.is_a?(Hash)
+ invalid_options = name.keys.map { |k| k.to_sym } - [:rdoc, :clobber_rdoc, :rerdoc]
+ if !invalid_options.empty?
+ raise ArgumentError, "Invalid option(s) passed to RDocTask.new: #{invalid_options.join(", ")}"
+ end
+ end
+
@name = name
@rdoc_files = Rake::FileList.new
@rdoc_dir = 'html'
@@ -74,6 +99,7 @@ module Rake
@title = nil
@template = nil
@external = false
+ @inline_source = true
@options = []
yield self if block_given?
define
@@ -81,27 +107,28 @@ module Rake
# Create the tasks defined by this task lib.
def define
- if name.to_s != "rdoc"
+ if rdoc_task_name != "rdoc"
desc "Build the RDOC HTML Files"
+ else
+ desc "Build the #{rdoc_task_name} HTML Files"
end
-
- desc "Build the #{name} HTML Files"
- task name
+ task rdoc_task_name
desc "Force a rebuild of the RDOC files"
- task "re#{name}" => ["clobber_#{name}", name]
+ task rerdoc_task_name => [clobber_task_name, rdoc_task_name]
desc "Remove rdoc products"
- task "clobber_#{name}" do
+ task clobber_task_name do
rm_r rdoc_dir rescue nil
end
- task :clobber => ["clobber_#{name}"]
+ task :clobber => [clobber_task_name]
directory @rdoc_dir
- task name => [rdoc_target]
+ task rdoc_task_name => [rdoc_target]
file rdoc_target => @rdoc_files + [Rake.application.rakefile] do
rm_r @rdoc_dir rescue nil
+ @before_running_rdoc.call if @before_running_rdoc
args = option_list + @rdoc_files
if @external
argstring = args.join(' ')
@@ -120,6 +147,7 @@ module Rake
result << "--main" << quote(main) if main
result << "--title" << quote(title) if title
result << "-T" << quote(template) if template
+ result << "--inline-source" if inline_source && !@options.include?("--inline-source") && !@options.include?("-S")
result
end
@@ -135,11 +163,45 @@ module Rake
option_list.join(' ')
end
+ # The block passed to this method will be called just before running the
+ # RDoc generator. It is allowed to modify RDocTask attributes inside the
+ # block.
+ def before_running_rdoc(&block)
+ @before_running_rdoc = block
+ end
+
private
def rdoc_target
"#{rdoc_dir}/index.html"
end
+ def rdoc_task_name
+ case name
+ when Hash
+ (name[:rdoc] || "rdoc").to_s
+ else
+ name.to_s
+ end
+ end
+
+ def clobber_task_name
+ case name
+ when Hash
+ (name[:clobber_rdoc] || "clobber_rdoc").to_s
+ else
+ "clobber_#{name}"
+ end
+ end
+
+ def rerdoc_task_name
+ case name
+ when Hash
+ (name[:rerdoc] || "rerdoc").to_s
+ else
+ "re#{name}"
+ end
+ end
+
end
end